%global minor_version %%(echo %{version} | cut -d. -f2)

Summary: Exif and Iptc metadata manipulation library
Name:    exiv2
Version: 0.28.1
Release: 1%{?dist}
License: GPLv2+
URL:     http://www.exiv2.org/
Source0: https://github.com/Exiv2/%{name}/archive/refs/tags/v%{version}.tar.gz

BuildRequires: cmake gcc-c++
BuildRequires: expat-devel pkgconfig zlib-devel brotli-devel inih-devel
BuildRequires: gettext doxygen graphviz libxslt
Requires: %{name}-libs = %{version}-%{release}

%description
This package provides a command line utility to access image metadata, including:
* print the Exif metadata of Jpeg images as summary info, interpreted values, or the plain data 
  for each tag
* print the Iptc metadata and the Jpeg comment of Jpeg images
* set, add and delete Exif and Iptc metadata of Jpeg images
* adjust the Exif timestamp and rename Exif image files according to the timestamp
* extract, insert and delete Exif metadata (including thumbnails), Iptc metadata and Jpeg comments

%package devel
Summary: Header files, libraries and development documentation for %{name}
Requires: %{name}-libs = %{version}-%{release}
%description devel
This packages contains Exif and Iptc metadata manipulation library.

%package libs
Summary: Exif and Iptc metadata manipulation library
Recommends: %{name} = %{version}-%{release}

%description libs
This package provides a C++ library to access image metadata, supporting full read and write 
access to the Exif and Iptc metadata, Exif MakerNote support, extract and delete methods for 
Exif thumbnails, classes to access Ifd and so on.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%cmake \
  -DCMAKE_INSTALL_DOCDIR="%{_pkgdocdir}" \
  -DEXIV2_BUILD_DOC:BOOL=ON \
  -DEXIV2_ENABLE_NLS:BOOL=ON \
  -DEXIV2_BUILD_SAMPLES:BOOL=OFF

%cmake_build
%cmake_build --target doc

%install
%cmake_install

%find_lang exiv2 --with-man


%check
export PKG_CONFIG_PATH="%{buildroot}%{_libdir}/pkgconfig${PKG_CONFIG_PATH:+:}${PKG_CONFIG_PATH}"
test "$(pkg-config --modversion exiv2)" = "%{version}"
test "$(pkg-config --variable=libdir exiv2)" = "%{_libdir}"
test -x %{buildroot}%{_libdir}/libexiv2.so


%files -f exiv2.lang
%license COPYING
%doc doc/ChangeLog
%{_bindir}/exiv2
%{_mandir}/man1/exiv2*.1*

%files libs
%{_libdir}/libexiv2.so.%{minor_version}*
%{_libdir}/libexiv2.so.%{version}

%files devel
%{_pkgdocdir}/
%{_includedir}/exiv2/
%{_libdir}/libexiv2.so
%{_libdir}/pkgconfig/exiv2.pc
%{_datadir}/cmake/exiv2/

%changelog
* Wed Jan 03 2024 Upgrade Robot <upbot@opencloudos.org> - 0.28.1-1
- Upgrade to version 0.28.1

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.27.5-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.27.5-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.27.5-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Dec 12 2022 Wang Guodong <gordonwwang@tencent.com> - 0.27.5-1
- package init.
